@@ -22,7 +22,7 @@ class PlotCpuUsageAgainstLatency(ReportSection):
 
         for scenario in results.scenarios():
             cpu_usages, latencies = self.service.get_data(scenario, self.endpoint_name)
-            plt.plot(cpu_usages, latencies, '--*', label=scenario.name())
+            plt.plot(cpu_usages, latencies, '--*', label=scenario.id())
 
             # plt.plot(trend['x'], trend['y'], 'r--', label='Trend line')
 
