@@ -37,6 +37,6 @@ class PlotCpuUsageOverTime(ReportSection):
 
     def draw_scenario_vlines(self):
         for scenario in self.service.scenarios():
-            label = "Start '{}'".format(scenario.name())
+            label = "Start '{}'".format(scenario.id())
 
             plt.axvline(x=scenario.started_at(), color=self.next_color(), linestyle='--', label=label)
