@@ -14,7 +14,7 @@ class PlotLatenciesOverTime(ReportSection):
 
     def draw_scenario_vlines(self, results: Results):
         for scenario in results.scenarios():
-            label = "Start '{}'".format(scenario.name())
+            label = "Start '{}'".format(scenario.id())
 
             plt.axvline(x=scenario.started_at(), color=self.next_color(), linestyle='--', label=label)
 
