@@ -40,7 +40,7 @@ class PlotTransactionSignatures(ReportSection):
         for scenario, signature in signatures:
             plt.gcf().subplots_adjust(bottom=0.5)
             plt.xticks(rotation=80)
-            plt.plot([s.endpoint_name for s in signature], [s.value for s in signature], label=scenario.name())
+            plt.plot([s.endpoint_name for s in signature], [s.value for s in signature], label=scenario.id())
 
         plt.xlabel('Endpoint')
         plt.legend()
@@ -72,7 +72,7 @@ class PlotTransactionSignatures(ReportSection):
                 y_values = [(s.value - base_signature[idx].value) / base_signature[idx].value * 100 for idx, s in
                             enumerate(signature)]
 
-            plt.plot(x_values, y_values, label=scenario.name())
+            plt.plot(x_values, y_values, label=scenario.id())
 
         plt.xlabel('Endpoint')
         plt.legend()
