@@ -8,11 +8,11 @@ class Sleep(Modifier):
 
     def modify(self, fun, endpoint_name, modifier_args: dict):
         def wrapper(*args, **kwargs):
-            sleep_for = int(modifier_args.get('time')) / 1000
+            sleep_ms = int(modifier_args.get('time'))
+            sleep_for = sleep_ms / 1000
+            print('Sleeping for {}ms'.format(sleep_ms))
             sleep(sleep_for)
 
-            print('Sleeping for {}ms'.format(sleep_for))
-
             return fun(*args, **kwargs)
 
-        return wrapper
\ No newline at end of file
+        return wrapper
