@@ -39,7 +39,7 @@ def start_new_scenario():
 
     print('Starting new scenario')
 
-    simulation.start_scenario(data['name'], data['modifiers'], data['options'])
+    simulation.start_scenario(data['id'], data['modifiers'], data['options'], data['meta'])
 
     return success()
 
@@ -58,13 +58,13 @@ def stop_running_scenario():
     cpu_usage_measurements = get_cpu_usage_measurements(start, end)
 
     data = {
-        'name': scenario.name(),
+        'id': scenario.id(),
         'cpu_usage_measurements': cpu_usage_measurements,
+        'meta': scenario.meta(),
         'started_at': start.isoformat(),
         'ended_at': end.isoformat(),
         'endpoints': []
     }
-
     for (endpoint_name, measurements) in latency_measurements.items():
         data['endpoints'].append(dict(
             name=endpoint_name,
@@ -103,7 +103,7 @@ def stop_simulation():
             start=scenario.started_at().isoformat(),
             end=scenario.ended_at().isoformat(),
             modifiers=scenario.modifiers(),
-            name=scenario.name(),
+            name=scenario.id(),
             options=scenario.options()
         ))
 
