@@ -20,9 +20,13 @@ class Api(object):
 
         return response.json()
 
-    def start_scenario(self, name, modifiers, meta, options):
-        payload = dict(modifiers=modifiers, meta=meta, name=name, options=options)
-        response = requests.post(self.host.url('/api/simulation/start-scenario'), json=payload)
+    def start_scenario(self, id, modifiers, options, meta):
+        response = requests.post(self.host.url('/api/simulation/start-scenario'), json=dict(
+            modifiers=modifiers,
+            id=id,
+            options=options,
+            meta=meta
+        ))
 
         assert response.status_code == 200
 
