@@ -3,7 +3,7 @@ from flask_scenario_testing.simulation.ScenariosConfig import ScenariosConfig
 import subprocess
 import json
 from time import sleep
-
+import os
 from flask_scenario_testing.support.Time import Time
 
 
@@ -22,16 +22,17 @@ class Simulation(object):
         print('Total number of scenarios: {}'.format(len(scenarios)))
 
         for i, scenario in enumerate(scenarios):
-            print('Deploying scenario "{}"'.format(scenario.name()))
+            print('Deploying scenario "{}"'.format(scenario.id()))
 
-            self.api.start_scenario(scenario.name(), scenario.modifiers(), scenario.users_count(), scenario.options())
+            self.api.start_scenario(scenario.id(), scenario.modifiers(), scenario.options(), scenario.meta())
 
             print('Starting load ...')
             self._run_locust(scenario.users_count(), scenario.run_time())
 
             results = self.api.stop_running_scenario()
 
-            with open(outputdir + '/' + results['data']['name'] + '.json', 'w') as outputfile:
+            absolute_path = os.path.join(outputdir, '{}.json'.format(results['data']['id']))
+            with open(absolute_path, 'w') as outputfile:
                 json.dump(results['data'], outputfile)
                 outputfile.flush()
 
@@ -46,7 +47,7 @@ class Simulation(object):
         self.api.stop_simulation()
 
     def _run_locust(self, users_count, total_run_time: Time):
-        args = [
+        p = subprocess.Popen([
             'locust',
             '-f', self.locustfile,
             '--host', self.api.host_url(),
@@ -54,8 +55,7 @@ class Simulation(object):
             '-u', str(users_count),
             '-r', str(users_count),
             '-t', str(total_run_time),
-        ]
-        p = subprocess.Popen(args)
+        ])
 
         run_time_left = total_run_time.seconds()
 
